@@ -75,15 +75,11 @@ complete_dates <- function(
     if (inherits(dates, "POSIXct") && !allow_POSIXct) {
         # TODO - Do we want/need a different error condition here?
         .stop(
-            "<POSIXct> date_index columns detected. Internally <POSIXct> objects ",
-            "are represented as seconds since the UNIX epoch and calling ",
-            "`complete_dates()` on an object of granularity can lead to ",
-            "significant memory usage. If you are sure you wish to do this, ",
-            "please call again with the argument `allow_POSIXct` set to `TRUE`. ",
-            "If this level of aggregation is not desired, consider recreating the ",
-            "<incidence> object using <Dates> for daily incidence. This can be done ",
-            "prior to calling `incidence()` or, alternatively, by setting the ",
-            "argument `interval = 'day'` within the call itself."
+            "<POSIXct> date_index columns detected. ",
+            "Internally <POSIXct> objects are represented as seconds since the UNIX epoch and calling `complete_dates()` on an object of granularity can lead to significant memory usage. ",
+            "If you are sure you wish to do this, please call again with the argument `allow_POSIXct` set to `TRUE`. ",
+            "If this level of aggregation is not desired, consider recreating the <incidence> object using <Dates> for daily incidence. ",
+            "This can be done prior to calling `incidence()` or, alternatively, by setting the argument `interval = 'day'` within the call itself."
         )
     }
 
