@@ -205,7 +205,7 @@ incidence <- function(
             .stopf("As of incidence 2.0.0, `%s` is no longer a valid parameter name. See `help('incidence')` for supported parameters.", nms[1L])
         }
         if (is.null(nms))
-            stop("Too many arguments given.")
+            .stop("Too many arguments given.")
 
         nms <- nms[nms != ""]
         .stopf("`%s` is not a valid parameter", nms[1L])
@@ -213,16 +213,16 @@ incidence <- function(
 
     # x must be a data frame
     if (!is.data.frame(x))
-        stop("`x` must be a data frame.")
+        .stop("`x` must be a data frame.")
 
     # count_names_to check
-    assert_scalar_character(count_names_to)
+    assert_scalar_character(count_names_to, .subclass = "incidence2_error")
 
     # count_values_to check
-    assert_scalar_character(count_values_to)
+    assert_scalar_character(count_values_to, .subclass = "incidence2_error")
 
     # date_names_to check
-    assert_scalar_character(date_names_to)
+    assert_scalar_character(date_names_to, .subclass = "incidence2_error")
 
     # boolean checks
     assert_bool(rm_na_dates)
@@ -233,66 +233,66 @@ incidence <- function(
     length_date_index <- length(date_index)
 
     if (!(is.character(date_index) && length_date_index))
-        stop("`date_index` must be a character vector of length 1 or more.")
+        .stop("`date_index` must be a character vector of length 1 or more.")
 
     if (anyDuplicated(date_index))
-        stop("`date_index` values must be unique.")
+        .stop("`date_index` values must be unique.")
 
     if (!all(date_index %in% names(x)))
-        stop("Not all variables from `date_index` are present in `x`.")
+        .stop("Not all variables from `date_index` are present in `x`.")
 
     date_cols <- .subset(x, date_index)
     date_classes <- vapply(date_cols, function(x) class(x)[1L], "")
     if (length(unique(date_classes)) != 1L)
-        stop("`date_index` columns must be of the same class.")
+        .stop("`date_index` columns must be of the same class.")
 
     # error if date_index cols are vctrs_rcrd type
     is_vctrs_rcrd <- vapply(date_cols, inherits, TRUE, what = "vctrs_rcrd")
     if (any(is_vctrs_rcrd))
-        stop("vctrs_rcrd date_index columns are not currently supported.")
+        .stop("vctrs_rcrd date_index columns are not currently supported.")
 
     # error if date_index cols are POSIXlt
     is_POSIXlt <- vapply(date_cols, inherits, TRUE, what = "POSIXlt")
     if (any(is_POSIXlt))
-        stop("POSIXlt date_index columns are not currently supported.")
+        .stop("POSIXlt date_index columns are not currently supported.")
 
     # counts checks
     if (!is.null(counts)) {
         if (!is.character(counts) || length(counts) < 1L)
-            stop("`counts` must be NULL or a character vector of length 1 or more.")
+            .stop("`counts` must be NULL or a character vector of length 1 or more.")
 
         if (anyDuplicated(counts))
-            stop("`counts` values must be unique.")
+            .stop("`counts` values must be unique.")
 
         if (length_date_index > 1L)
-            stop("If `counts` is specified `date_index` must be of length 1.")
+            .stop("If `counts` is specified `date_index` must be of length 1.")
     }
 
     if (!all(counts %in% names(x)))
-        stop("Not all variables from `counts` are present in `x`.")
+        .stop("Not all variables from `counts` are present in `x`.")
 
     # group checks
     if (!(is.null(groups) || is.character(groups)))
-        stop("`groups` must be NULL or a character vector.")
+        .stop("`groups` must be NULL or a character vector.")
 
     if (length(groups)) {
         # ensure groups are present
         if (!all(groups %in% names(x)))
-            stop("Not all variables from `groups` are present in `x`.")
+            .stop("Not all variables from `groups` are present in `x`.")
 
         if (anyDuplicated(groups))
-            stop("`group` values must be unique.")
+            .stop("`group` values must be unique.")
 
         # error if group cols are vctrs_rcrd type
         group_cols <- .subset(x, groups)
         is_vctrs_rcrd <- vapply(group_cols, inherits, TRUE, what = "vctrs_rcrd")
         if (any(is_vctrs_rcrd))
-            stop("vctrs_rcrd group columns are not currently supported.")
+            .stop("vctrs_rcrd group columns are not currently supported.")
 
         # error if group cols are POSIXlt
         is_POSIXlt <- vapply(group_cols, inherits, TRUE, what = "POSIXlt")
         if (any(is_POSIXlt))
-            stop("POSIXlt group columns are not currently supported.")
+            .stop("POSIXlt group columns are not currently supported.")
     }
 
     # check interval and apply transformation across date index
@@ -300,7 +300,7 @@ incidence <- function(
 
         # check interval is valid length
         if (length(interval) != 1L)
-            stop("`interval` must be a character or integer vector of length 1.")
+            .stop("`interval` must be a character or integer vector of length 1.")
 
         # For numeric we coerce to integer and use as_period
         if (is.numeric(interval)) {
@@ -308,7 +308,7 @@ incidence <- function(
 
             if (is.numeric(date_cols[[1L]])) {
                 if (!is.null(offset))
-                    stop("`offset` can only be used with non-numeric date input.")
+                    .stop("`offset` can only be used with non-numeric date input.")
                 x[date_index] <- lapply(x[date_index], as_int_period, n = n)
             } else {
                 # coerce offset (do here rather than in grates for better easier error messaging)
@@ -317,7 +317,7 @@ incidence <- function(
                         offset <- floor(as.numeric(offset))
 
                     if (!.is_scalar_whole(offset))
-                        stop("`offset` must be an integer or date of length 1.")
+                        .stop("`offset` must be an integer or date of length 1.")
                 } else {
                     offset <- 0L
                 }
@@ -325,7 +325,7 @@ incidence <- function(
             }
         } else if (!is.null(offset)) {
             # offset only valid for numeric interval
-            stop("`offset` can only be used with a numeric (period) interval.")
+            .stop("`offset` can only be used with a numeric (period) interval.")
         } else if (is.character(interval)) {
             # We are restrictive on intervals we allow to keep the code simple.
             # Users can always call grates functionality directly (reccomended)
@@ -353,7 +353,7 @@ incidence <- function(
                 year        =,
                 years       =,
                 yearly       = as_year,
-                stop(paste(
+                .stop(paste(
                     "`interval` must be one of:",
                     "    - an <integer> value;",
                     "    - 'day' or 'daily';",
@@ -367,26 +367,32 @@ incidence <- function(
             )
             x[date_index] <- lapply(x[date_index], FUN)
         } else {
-            stop("`interval` must be a character or integer vector of length 1.")
+            .stop("`interval` must be a character or integer vector of length 1.")
         }
     } else if (any(vapply(date_cols, inherits, TRUE, what = "POSIXct"))) {
         .warn(
-            "<POSIXct> date_index columns detected. Internally <POSIXct> objects ",
-            "are represented as seconds since the UNIX epoch and, in our experience, ",
-            "this level of granularity is not normally desired for aggregation. ",
-            "For daily incidence consider converting the inputs to <Dates>. This can ",
-            "be done prior to calling `incidence()` or, alternatively, by setting the ",
-            "argument `interval = 'day'` within the call itself."
+            "<POSIXct> date_index columns detected. ",
+            "Internally <POSIXct> objects are represented as seconds since the UNIX epoch and, in our experience, this level of granularity is not normally desired for aggregation. ",
+            "For daily incidence consider converting the inputs to <Dates>. ",
+            "This can be done prior to calling `incidence()` or, alternatively, by setting the argument `interval = 'day'` within the call itself."
         )
 
         if (complete_dates) {
             # TODO - Do we want/need a different error condition here?
             .stop(
-                "`complete_dates = TRUE` is not compatible with <POSIXct> ",
-                "date_index columns due to the aforementioned warning. ",
-                "If you wish to use <POSIXct> columns then set `complete_dates = FALSE` ",
-                "and call the `complete_dates()` function directly after the call ",
-                "to incidence."
+                "`complete_dates = TRUE` is not compatible with <POSIXct> date_index columns due to the aforementioned warning. ",
+                "If you wish to use <POSIXct> columns then set `complete_dates = FALSE` and call the `complete_dates()` function directly after the call to incidence."
+            )
+        }
+    } else if (inherits(date_cols[[1L]], "Date")) {
+        whole <- vapply(date_cols, .is_whole_or_NA, TRUE)
+        if (!all(whole)) {
+            not_whole <- date_index[!whole]
+            .warn(
+                "Non-whole <Date> columns detected. ",
+                "These can be confusing as they are displayed without the fractional element and can also cause oddities when plotting. ",
+                "If you are interested in daily incidence, consider removing the fractional part. ",
+                "This can be done prior to calling `incidence()` or, alternatively, by setting the argument `interval = 'day'` within the call itself."
             )
         }
     }
@@ -498,7 +504,7 @@ incidence <- function(
         assert_scalar_numeric(fill)
         out <- complete_dates(out, fill = fill)
     } else if (!missing(fill)) {
-        stop("`fill` can only be given when `complete_dates = TRUE`.")
+        .stop("`fill` can only be given when `complete_dates = TRUE`.")
     }
 
     out
@@ -528,7 +534,7 @@ incidence_ <- function(
     date_position <- tidyselect::eval_select(date_expr, data = x)
     length_date_index <- length(date_position)
     if (!length_date_index)
-        stop("`date_index` must be of length 1 or more.")
+        .stop("`date_index` must be of length 1 or more.")
     date_index <- names(date_position)
     names(x)[date_position] <- date_index
 
@@ -537,11 +543,11 @@ incidence_ <- function(
     counts_position <- tidyselect::eval_select(counts_expr, data = x)
     if (length(counts_position)) {
         if (length_date_index > 1L)
-            stop("If `counts` is specified `date_index` must be of length 1.")
+            .stop("If `counts` is specified `date_index` must be of length 1.")
         counts <- names(counts_position)
         names(x)[counts_position] <- counts
     } else if (!is.null(counts)) {
-        stop("`counts` must be NULL or a column in `x`.")
+        .stop("`counts` must be NULL or a column in `x`.")
     }
 
     # group checks
@@ -554,13 +560,13 @@ incidence_ <- function(
 
     # ensure selected columns are distinct
     if (length(intersect(date_index, groups)))
-        stop("`date_index` columns must be distinct from `groups`.")
+        .stop("`date_index` columns must be distinct from `groups`.")
 
     if (length(intersect(date_index, counts)))
-        stop("`date_index` columns must be distinct from `counts`.")
+        .stop("`date_index` columns must be distinct from `counts`.")
 
     if (length(intersect(groups, counts)))
-        stop("`group` columns must be distinct from `counts`.")
+        .stop("`group` columns must be distinct from `counts`.")
 
     incidence(
         x = x,
