@@ -1,3 +1,61 @@
+test_that("Fails with good error for bad input", {
+    dat <- data.frame(
+        dates = Sys.Date() + 1:10,
+        count = 1:10,
+        dates2 = Sys.Date() + 11:20
+    )
+
+    expect_snapshot(error = TRUE, incidence_("bob"))
+    expect_snapshot(error = TRUE, incidence_(dat, date_index = character()))
+    expect_snapshot(error = TRUE, incidence_(dat, date_index = bob))
+    expect_snapshot(error = TRUE, incidence_(dat, date_index = dates, counts = character()))
+    expect_snapshot(error = TRUE, incidence_(dat, date_index = c(dates, dates2), counts = count),)
+    expect_snapshot(error = TRUE, incidence_(dat, date_index = dates, counts = bob))
+    expect_snapshot(error = TRUE, incidence_(dat, date_index = dates, counts = count, groups = 1))
+
+    dat2 <- transform(dat, dates = as.POSIXlt(dates))
+    expect_snapshot(error = TRUE, incidence_(dat2, date_index = dates))
+})
+
+test_that("miscellaneous incidence error messaging works as expected", {
+    dat <- data.frame(
+        dates = Sys.Date() + 1:10,
+        count = 1:10,
+        dates2 = Sys.Date() + 11:20
+    )
+
+    # TODO - consider if we want to rethrow this
+    expect_error(incidence_("bob"))
+
+    # NOTE - altered from incidence() test due to tidyselect
+    expect_error(incidence_(dat, date_index = character()))
+
+    # NOTE - altered from incidence() test due to tidyselect
+    expect_error(incidence_(dat, date_index = bob))
+
+    dat2 <- transform(dat, dates = as.POSIXlt(dates))
+    expect_error(incidence_(dat2, date_index = dates))
+
+    # NOTE - altered from incidence() test due to tidyselect
+    expect_error(incidence_(dat, date_index = dates, counts = character()))
+
+    expect_error(incidence_(dat, date_index = c(dates, dates2), counts = count))
+
+    # TODO - I'd like this to error but need to work out how
+    # expect_error(
+    #     incidence_(dat, date_index = c(dates, dates), counts = count),
+    #     "`date_index` values must be unique.",
+    #     fixed = TRUE
+    # )
+
+    # NOTE - altered from incidence() test due to tidyselect
+    expect_error(incidence_(dat, date_index = dates, counts = bob))
+
+    # NOTE - altered from incidence() test due to tidyselect
+    expect_error(incidence_(dat, date_index = dates, counts = count, groups = 1))
+})
+
+
 test_that("incidence_ with no groupings and no intervals works", {
     firstday <- as.Date("2020-01-01") # Wednesday
     lastday <- as.Date("2021-12-31")  # Friday
@@ -400,62 +458,3 @@ test_that("10 incidence with no groupings but with a count works", {
     expect_equal(as.Date(x$date_index), expected_dates)
     expect_equal(x$count, expected_counts)
 })
-
-
-test_that("miscellaneous incidence error messaging works as expected", {
-    dat <- data.frame(
-        dates = Sys.Date() + 1:10,
-        count = 1:10,
-        dates2 = Sys.Date() + 11:20
-    )
-
-    # TODO - consider if we want to rethrow this
-    expect_error(incidence_("bob"))
-
-    # NOTE - altered from incidence() test due to tidyselect
-    expect_error(
-        incidence_(dat, date_index = character()),
-        "`date_index` must be of length 1 or more.",
-        fixed = TRUE
-    )
-
-    # NOTE - altered from incidence() test due to tidyselect
-    expect_error(incidence_(dat, date_index = bob))
-
-    dat2 <- transform(dat, dates = as.POSIXlt(dates))
-    expect_error(
-        incidence_(dat2, date_index = dates),
-        "POSIXlt date_index columns are not currently supported.",
-        fixed = TRUE
-    )
-
-    # NOTE - altered from incidence() test due to tidyselect
-    expect_error(incidence_(dat, date_index = dates, counts = character()))
-
-    expect_error(
-        incidence_(dat, date_index = c(dates, dates2), counts = count),
-        "If `counts` is specified `date_index` must be of length 1.",
-        fixed = TRUE
-    )
-
-    # TODO - I'd like this to error but need to work out how
-    # expect_error(
-    #     incidence_(dat, date_index = c(dates, dates), counts = count),
-    #     "`date_index` values must be unique.",
-    #     fixed = TRUE
-    # )
-
-    # NOTE - altered from incidence() test due to tidyselect
-    expect_error(incidence_(dat, date_index = dates, counts = bob))
-
-    # NOTE - altered from incidence() test due to tidyselect
-    expect_error(
-        incidence_(dat, date_index = dates, counts = count, groups = 1),
-        "`date_index` columns must be distinct from `groups`.",
-        fixed = TRUE
-    )
-
-
-
-
-})
